/*
 *COPYRIGHT LICENSE: This information contains sample code provided in source code form.
 * You may copy, modify, and distribute these sample programs in any form without payment
 * to IBM for the purposes of developing, using, marketing or distributing application
 * programs conforming to the application programming interface for the operating platform
 * for which the sample code is written.
 *
 * Notwithstanding anything to the contrary, IBM PROVIDES THE SAMPLE SOURCE CODE ON 
 * AN "AS IS" BASIS AND IBM DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, INCLUDING,
 * BUT NOT LIMITED TO, ANY IMPLIED WARRANTIES OR CONDITIONS OF MERCHANTABILITY,
 * SATISFACTORY QUALITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND ANY WARRANTY OR
 * CONDITION OF NON-INFRINGEMENT. IBM SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF
 * THE SAMPLE SOURCE CODE. IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS OR MODIFICATIONS TO THE SAMPLE SOURCE CODE.
 *
 * (C) Copyright IBM Corp. 2001, 2013.
 * All Rights Reserved. Licensed Materials - Property of IBM.
 */
package com.ibm.ws.samples.jsf.bean;

import java.io.Serializable;
import java.util.List;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import javax.faces.event.ValueChangeEvent;

import com.ibm.ws.samples.jsf.manager.MockUserManager;
import com.ibm.ws.samples.jsf.manager.UserManager;

/**
 * The bean represents the User object.
 * 
 */
@ManagedBean(name = "userBean")
@RequestScoped
public class UserBean implements Serializable {
	private static final long serialVersionUID = 5704701308929697924L;

	private final static String SUCCESS = "default";

	private UserManager userMgr = MockUserManager.getInstance();

	boolean validAge = true;
	
	private String name;
	private String gender;
	private String age;
	
	private List<UserBean> allUsers;

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getGender() {
		return gender;
	}

	public void setGender(String gender) {
		this.gender = gender;
	}

	public String getAge() {
		return age;
	}

	public void setAge(String age) {
		if (validAge) {
			this.age = age;
		} else {
			this.age = "0";
		}
	}

	public String create() {
		userMgr.storeUser(this);
		return SUCCESS;
	}

	public List<UserBean> getAllUsers() {
		allUsers = userMgr.getAllUsers();
		return allUsers;
	}
	
	public void nameChanged(ValueChangeEvent e) {
		name = e.getNewValue().toString();
	}
	
	public void genderChanged(ValueChangeEvent e) {
		gender = e.getNewValue().toString();
	}
	
	public void ageChanged(ValueChangeEvent e) {
		try {
			int tmpAge = Integer.parseInt( e.getNewValue().toString());
			if (tmpAge < 0 || tmpAge > 100) {
				validAge = false;
			}
		} catch (Exception exp) {
			validAge = false;
		}
	}

	public String editAction(String id) {
		System.out.println(id);
		return "createUser";
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		UserBean other = (UserBean) obj;
		if (name == null) {
			if (other.name != null)
				return false;
		} else if (!name.equals(other.name))
			return false;
		return true;
	}
	

}
